-----------------------------------------------------------------------------------------------
-- Client Lua Script for LibSimpleBarsDemo
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Apollo"
 
-----------------------------------------------------------------------------------------------
-- LibSimpleBarsDemo Module Definition
-----------------------------------------------------------------------------------------------
local LibSimpleBarsDemo = {} 


 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function LibSimpleBarsDemo:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    return o
end

function LibSimpleBarsDemo:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- LibSimpleBarsDemo OnLoad
-----------------------------------------------------------------------------------------------
function LibSimpleBarsDemo:OnLoad()
	self.xmlDoc = XmlDoc.CreateFromFile("LibSimpleBarsDemo.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- LibSimpleBarsDemo OnDocLoaded
-----------------------------------------------------------------------------------------------
function LibSimpleBarsDemo:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then

		self.wndContainer = Apollo.LoadForm(self.xmlDoc, "BarContainer", nil, self)
		
		self.wndBars = self.wndContainer:FindChild("ItemList")
		Apollo.RegisterSlashCommand("lsbdemo","OnDemo",self)
	end
end

-----------------------------------------------------------------------------------------------
-- LibSimpleBarsDemo Functions
-----------------------------------------------------------------------------------------------

function LibSimpleBarsDemo:OnDemo()
		self:CreateBar1()
		self:CreateBar2()
		self:CreateBar3()
		self:CreateBar4()
		self:CreateBar5()
end

function LibSimpleBarsDemo:OnBarStop(objBar)
	Print("Bar "..objBar.id.." finished!")
	Sound.Play(168)
end

function LibSimpleBarsDemo:OnBarUpdate(objBar)
	local timeFloor = math.floor(objBar.timeRemaining)
	if  timeFloor <= 5 and objBar.timeRemaining - timeFloor < 0.10 then
		Print("Bar "..objBar.id.." finishes in "..timeFloor.."!")
	end
end

function LibSimpleBarsDemo:CreateBar1()
	local id, wndParent, intWidth, intHeight = 1, self.wndBars, nil, nil
	local label = "Default bar"
	local duration = 60

-- shouldn't really be here, but for the demo's simplicity sake...	
	local lsb = Apollo.GetPackage("LibSimpleBars-1.0").tPackage
	bar = lsb.CreateBar(id, wndParent, intWidth, intHeight)

	self.wndBars:ArrangeChildrenVert(0, nil)

	bar:SetLabel(label)
	bar:SetDuration(duration)

	bar:Start()

end

function LibSimpleBarsDemo:CreateBar2()
	local id, wndParent, intWidth, intHeight = 3, self.wndBars, nil, nil
	local label = "Icon bar"
	local duration = 60
	
-- shouldn't really be here, but for the demo's simplicity sake...	
	local lsb = Apollo.GetPackage("LibSimpleBars-1.0").tPackage
	bar = lsb.CreateBar(id, wndParent, intWidth, intHeight)

	self.wndBars:ArrangeChildrenVert(0, nil)

	bar:SetLabel(label)
	bar:SetDuration(duration)
	
	bar:SetIcon("CRB_BreakoutSprites:spr_BreakoutStun_ClockOrange")
	bar:SetValue(5)
	bar:Start()

end

function LibSimpleBarsDemo:CreateBar3()
	local id, wndParent, intWidth, intHeight = 2, self.wndBars, nil, nil
	local label = "Filling bar"
	local duration = 60
	
-- shouldn't really be here, but for the demo's simplicity sake...	
	local lsb = Apollo.GetPackage("LibSimpleBars-1.0").tPackage
	bar = lsb.CreateBar(id, wndParent, intWidth, intHeight)

	self.wndBars:ArrangeChildrenVert(0, nil)

	bar:SetLabel(label)
	bar:SetDuration(duration)
	
	bar:SetFill(true)
	bar:SetValue(10)
	bar:Start()

end

function LibSimpleBarsDemo:CreateBar4()
	local id, wndParent, intWidth, intHeight = 5, self.wndBars, nil, nil
	local label = "onUpdate & onFinish callbacks"
	local duration = 60
	
-- shouldn't really be here, but for the demo's simplicity sake...	
	local lsb = Apollo.GetPackage("LibSimpleBars-1.0").tPackage
	bar = lsb.CreateBar(id, wndParent, intWidth, intHeight)

	self.wndBars:ArrangeChildrenVert(0, nil)

	bar:SetLabel(label)
	bar:SetDuration(duration)

	bar:AddOnUpdateCallback("OnBarUpdate", self)
	bar:AddOnFinishCallback("OnBarStop", self)
	
	bar:SetValue(15)
	
	bar:Start()

end

function LibSimpleBarsDemo:CreateBar5()
	local id, wndParent, intWidth, intHeight = 4, self.wndBars, 300, 40
	local label = "Custom size & textures"
	local duration = 60
	
-- shouldn't really be here, but for the demo's simplicity sake...	
	local lsb = Apollo.GetPackage("LibSimpleBars-1.0").tPackage
	bar = lsb.CreateBar(id, wndParent, intWidth, intHeight)

	self.wndBars:ArrangeChildrenVert(0, nil)

	bar:SetLabel(label)
	bar:SetDuration(duration)
	bar:SetIcon("CRB_BreakoutSprites:spr_BreakoutStun_ClockOrange")

	bar:SetTextureBar("BasicSprites:LineFill", "red")
	bar:SetTextureBG("")

	bar:SetValue(20)
	
	bar:Start()

end

-----------------------------------------------------------------------------------------------
-- LibSimpleBarsDemo Instance
-----------------------------------------------------------------------------------------------
local LibSimpleBarsDemoInst = LibSimpleBarsDemo:new()
LibSimpleBarsDemoInst:Init()
